
#include "msp430.h"
#include <stdint.h>
#include "uart.h"
#define TIMEOUT_COUNT   1500000



void BSL_sendSingleByte(uint8_t ui8Byte) {
    uint32_t timeout = TIMEOUT_COUNT;
    while ((!(UCA0IFG & UCTXIFG)) && (timeout-- > 0))
        ;

    if (!timeout)
        return;
    else
        UCA0TXBUF = ui8Byte;
}

uint8_t BSL_programMemorySegment(uint32_t addr, const uint8_t* data,
        uint32_t len)
{
    uint16_t xferLen;
    uint8_t res;

    while (len > 0)
    {
        if (len > 16)
        {
            xferLen = 16;
        } else
        {
            xferLen = len;
        }

        tBSLPacket tPacket;
        tPacket.tPayload.ui8Command = BSL_RX_APP_CMD;
        tPacket.tPayload.ui8pData = data;
        tPacket.ui8Length = xferLen + 4;
        tPacket.tPayload.ui8Addr_H = ((uint8_t) (addr >> 16));
        tPacket.tPayload.ui8Addr_M = ((uint8_t) (addr >> 8));
        tPacket.tPayload.ui8Addr_L = ((uint8_t) (addr & 0xFF));
        tPacket.ui16Checksum = crc16MakeBitwise(tPacket);
        BSL_sendPacket(tPacket);
        //TEST
        if(addr >= 0x23F00)
            __no_operation();
        //END TEST
        res = BSL_getResponse();

        if (res != BSL_OK_RES)
            break;

        len -= xferLen;
        addr += xferLen;
        data += xferLen;
    }

    return res;
}




uint8_t BSL_sendCommand(uint8_t cmd)
{
    tBSLPacket tPacket;
    tPacket.ui8Header = BSL_HEADER;
    tPacket.tPayload.ui8Command = cmd;
    tPacket.ui8Length = 1;
    tPacket.ui16Checksum = crc16MakeBitwise(tPacket);
    BSL_sendPacket(tPacket);

    if(cmd != BSL_JMP_APP_CMD)
        __delay_cycles(10);
        return BSL_getResponse();

    //return 0;
}


void BSL_sendPacket(tBSLPacket tPacket) {
    uint16_t ii;
    volatile uint8_t crch, crcl;

    BSL_sendSingleByte(0x80);
    BSL_sendSingleByte(tPacket.ui8Length);
    BSL_sendSingleByte(tPacket.tPayload.ui8Command);

    if (tPacket.ui8Length > 1) {
        BSL_sendSingleByte(tPacket.tPayload.ui8Addr_L);
        BSL_sendSingleByte(tPacket.tPayload.ui8Addr_M);
        BSL_sendSingleByte(tPacket.tPayload.ui8Addr_H);
        for (ii = 0; ii < (tPacket.ui8Length - 4); ii++) {
            BSL_sendSingleByte(tPacket.tPayload.ui8pData[ii]);
        }
    }

    crcl = (uint8_t) (tPacket.ui16Checksum & 0xFF);
    BSL_sendSingleByte(crcl);

    crch = (uint8_t) (tPacket.ui16Checksum >> 8);
    BSL_sendSingleByte(crch);

}


uint16_t crc16MakeBitwise(tBSLPacket tPacket)
{
    uint16_t i;

    CRCINIRES = 0xFFFF;

    uint8_t* pmsg = (uint8_t*)&tPacket.tPayload;

    uint16_t msg_size = tPacket.ui8Length;

    for(i = 0 ; i < msg_size ; i ++)
    {
        if(i < 4)
            CRCDIRB_L = pmsg[i];
        else if(i == 4)
        {
            pmsg = (uint8_t*)tPacket.tPayload.ui8pData;
            CRCDIRB_L = pmsg[i-4];
        }
        else
        {
            CRCDIRB_L = pmsg[i-4];
        }

    }

    return CRCINIRES;
}



uint8_t BSL_getResponse(void) {
    uint32_t timeout = TIMEOUT_COUNT;

    while ((!(UCA0IFG & UCRXIFG)) && (timeout-- > 0));

    if (!timeout)
        return 0xFF;
    else
        return UCA0RXBUF;

}
