//
//               MSP430FR2433                 MSP430F2433
//                   Host                        Target
//             -----------------          -----------------
//        /|\ |        P1.5/RXD |<-----+->|P1.4/TXD         | /|\
//        -o--|P2.3             |         |             P2.7|--o-
//        \|/ |        P1.4/TXD |<-+----->|P1.5/RXD         | \|/
//            |                 |         |                 |
//     LED <--|P1.0             |         |             P1.0|--> LED
//     LED <--|P1.1          GND|<-+----->|GND          P1.1|--> LED
//             -----------------          -----------------



#include "msp430.h"
#include "TI_MSPBoot_Common.h"
#include "TI_MSPBoot_CI.h"
#include "TI_MSPBoot_MI.h"
#include "TI_MSPBoot_AppMgr.h"



//  Local function prototypes


void Software_Trim();                       // Software Trim to get the best DCOFTRIM value
#define MCLK_FREQ_MHZ 8                     // MCLK = 8MHz

static void clock_init(void);
tBOOL TI_MSPBoot_AppMgr_AppisValid(void);

//char* JmpToApp;

char JmpToApp,jumpToApp2;
unsigned char *addr = NULL;
char app1_downloaded,app2_start,app2_end;



/******************************************************************************
 *
 * @brief   Main function
 *  - Initializes the MCU
 *  - Selects whether to run application or bootloader
 *  - If bootloader:
 *      - Initializes the peripheral interface
 *      - Waits for a command
 *      - Sends the corresponding response
 *  - If application:
 *      - Jump to application
 *
 * @return  none
 *****************************************************************************/
void main_boot(void)
{

    WDTCTL = WDTPW + WDTHOLD;
    //JmpToApp = (char *)0x4000;


    PM5CTL0 &= ~LOCKLPM5;
    clock_init();
    __bis_SR_register(GIE);

    P4DIR |= BIT7;
    P4OUT |= BIT7;
    __delay_cycles(5000);
    P4OUT &= ~BIT7;


    addr = (unsigned char*) 0x1804;
    JmpToApp = *addr;

    //if ((*JmpToApp) == 1)
    if (JmpToApp == 1)
    {
            __disable_interrupt();
            ((void (*)()) 0x8004)();
    }

    if(JmpToApp == 2)
    {
        //jumpToApp2 = 0;
        __disable_interrupt();
        ((void (*)()) 0x81BE)();
    }
    // Validate the application and jump if needed
    if (TI_MSPBoot_AppMgr_ValidateApp() == TRUE_t)
    {
        __no_operation();
        TI_MSPBoot_APPMGR_JUMPTOAPP();
    }


    TI_MSPBoot_CI_Init();      // Initialize the Communication Interface

    while (1)
    {

        // Poll PHY and Data Link interface for new packets
       TI_MSPBoot_CI_PHYDL_Poll();



        if (app1_downloaded == 1 && app2_start == 1 && app2_end == 0)
        {
            __disable_interrupt();
            ((void (*)()) 0x8004)();
        }


        // If a new packet is detected, process it
        if (TI_MSPBoot_CI_Process() == RET_JUMP_TO_APP)
        {

            // If Packet indicates a jump to App
            //*JmpToApp = 1;

            //JmpToApp = 1;

            if (app1_downloaded == 1)
            {
                addr = (unsigned char*) 0x1804;
                SYSCFG0 = FRWPPW | PFWP;
                *addr = 2;
                SYSCFG0 = FRWPPW | DFWP | PFWP;
            }
            else if (app1_downloaded != 1)
            {
                addr = (unsigned char*) 0x1804;
                SYSCFG0 = FRWPPW | PFWP;
                *addr = 1;
                SYSCFG0 = FRWPPW | DFWP | PFWP;
            }

            app1_downloaded = 1;
            TI_MSPBoot_AppMgr_JumpToApp();

        }


#ifdef NDEBUG
        // Feed the dog every ~1000ms
        WATCHDOG_FEED();
#endif
   }

}





/******************************************************************************
 *
 * @brief   Initializes the MSP430 Clock
 *
 * @return  none
 *****************************************************************************/
//inline static void clock_init(void)



static void clock_init(void)
{
    CSCTL1 = DCOFTRIMEN | DCOFTRIM0 | DCOFTRIM1 | DCORSEL_3;   // Set DCO = 8Mhz
    CSCTL2 = FLLD_0 + 243;                   // DCODIV = 8MHz
    __delay_cycles(3);
    __bic_SR_register(SCG0);                 // enable FLL
    //Software_Trim();                         // Software Trim to get the best DCOFTRIM value
    CSCTL4 = SELA__REFOCLK + SELMS__DCOCLKDIV;                // set ACLK = VLO
    // MCLK=SMCLK=DC

#if (MCLK==1000000)
    CSCTL5 = DIVS__8 + DIVM__8;                 // Divide DCO/8
#elif (MCLK==4000000)
    CSCTL5 = DIVS__2 + DIVM__2;                 // Divide DCO/2
    #elif (MCLK==8000000)
    CSCTL5 = DIVS__1 + DIVM__1;                          // Divide DCO/1
#else
#error "Please define a valid MCLK or add configuration"
#endif

}



void Software_Trim()
{
    unsigned int oldDcoTap = 0xffff;
    unsigned int newDcoTap = 0xffff;
    unsigned int newDcoDelta = 0xffff;
    unsigned int bestDcoDelta = 0xffff;
    unsigned int csCtl0Copy = 0;
    unsigned int csCtl1Copy = 0;
    unsigned int csCtl0Read = 0;
    unsigned int csCtl1Read = 0;
    unsigned int dcoFreqTrim = 3;
    unsigned char endLoop = 0;

    do
    {
        CSCTL0 = 0x100;                         // DCO Tap = 256
        do
        {
            CSCTL7 &= ~DCOFFG;                  // Clear DCO fault flag
        }
        while (CSCTL7 & DCOFFG);               // Test DCO fault flag

        __delay_cycles((unsigned int) 3000 * MCLK_FREQ_MHZ); // Wait FLL lock status (FLLUNLOCK) to be stable
                                                             // Suggest to wait 24 cycles of divided FLL reference clock
        while ((CSCTL7 & (FLLUNLOCK0 | FLLUNLOCK1)) && ((CSCTL7 & DCOFFG) == 0))
            ;

        csCtl0Read = CSCTL0;                   // Read CSCTL0
        csCtl1Read = CSCTL1;                   // Read CSCTL1

        oldDcoTap = newDcoTap;               // Record DCOTAP value of last time
        newDcoTap = csCtl0Read & 0x01ff;       // Get DCOTAP value of this time
        dcoFreqTrim = (csCtl1Read & 0x0070) >> 4;       // Get DCOFTRIM value

        if (newDcoTap < 256)                    // DCOTAP < 256
        {
            newDcoDelta = 256 - newDcoTap; // Delta value between DCPTAP and 256
            if ((oldDcoTap != 0xffff) && (oldDcoTap >= 256)) // DCOTAP cross 256
                endLoop = 1;                   // Stop while loop
            else
            {
                dcoFreqTrim--;
                CSCTL1 = (csCtl1Read & (~(DCOFTRIM0 + DCOFTRIM1 + DCOFTRIM2)))
                        | (dcoFreqTrim << 4);
            }
        }
        else                                   // DCOTAP >= 256
        {
            newDcoDelta = newDcoTap - 256; // Delta value between DCPTAP and 256
            if (oldDcoTap < 256)                // DCOTAP cross 256
                endLoop = 1;                   // Stop while loop
            else
            {
                dcoFreqTrim++;
                CSCTL1 = (csCtl1Read & (~(DCOFTRIM0 + DCOFTRIM1 + DCOFTRIM2)))
                        | (dcoFreqTrim << 4);
            }
        }

        if (newDcoDelta < bestDcoDelta)         // Record DCOTAP closest to 256
        {
            csCtl0Copy = csCtl0Read;
            csCtl1Copy = csCtl1Read;
            bestDcoDelta = newDcoDelta;
        }

    }
    while (endLoop == 0);                      // Poll until endLoop == 1

    CSCTL0 = csCtl0Copy;                       // Reload locked DCOTAP
    CSCTL1 = csCtl1Copy;                       // Reload locked DCOFTRIM
    while (CSCTL7 & (FLLUNLOCK0 | FLLUNLOCK1)); // Poll until FLL is locked
}


tBOOL TI_MSPBoot_AppMgr_AppisValid(void)
{
    extern uint16_t _Appl_Start_Memory;
    extern uint16_t _Appl_CRC_Size1;
    extern uint16_t _Appl_Checksum;   // Address of A area checksum

    uint32_t i;
    uint8_t* data_ptr;
    static uint16_t result = 0;

    CRCINIRES = 0xFFFF;
    data_ptr = (uint8_t*) &_Appl_Start_Memory;
#pragma diag_suppress=770
    for(i = 0 ; i < (uint16_t) &_Appl_CRC_Size1 ; i++)
       {
        CRCDIRB_L = *data_ptr++;
       }
//#pragma diag_suppress=770
    result = CRCINIRES;
    if (result != __data20_read_short((unsigned short)&_Appl_Checksum)) return FALSE_t;
    else return TRUE_t;

}
