/******************************************************************************/
/* LINKER COMMAND FILE FOR MSPBoot BOOTLOADER USING msp430fr2476  */
/* File generated with MSPBootLinkerGen.py on 2024-04-11 */
/*----------------------------------------------------------------------------*/


/****************************************************************************/
/* SPECIFY THE SYSTEM MEMORY MAP                                            */
/****************************************************************************/
/* The following definitions can be changed to customize the memory map for a different device
 *   or other adjustments
 *  Note that the changes should match the definitions used in MEMORY and SECTIONS
 *
 */
/* RAM Memory Addresses */
__RAM_Start = 0x2000;                 /* RAM Start */
__RAM_End = 0x3fff;                     /* RAM End */
    /* RAM shared between App and Bootloader, must be reserved */
    PassWd = 0x2000;                 /* Password sent by App to force boot  mode */
    StatCtrl = 0x2002;             /* Status and Control  byte used by Comm */
    CI_State_Machine = 0x2003;         /*  State machine variable used by Comm */
    CI_Callback_ptr = 0x2004;   /* Pointer to Comm callback structure */
    /* Unreserved RAM used for Bootloader or App purposes */
    _NonReserved_RAM_Start = 0x2008; /* Non-reserved RAM */

/* Flash memory addresses */ 
__Flash_Start = 0x8000;             /* Start of Application area */
   /* Reserved Flash locations for Bootloader Area */
    __Boot_Start = 0xf400;         /* Boot flash */
    __Boot_Reset = 0xFFFE;                          /* Boot reset vector */
    __Boot_VectorTable = 0xFFA2;      /* Boot vector table */
    __Boot_SharedCallbacks_Len = 0x10; /* Length of shared callbacks (2 calls =4B(msp430) or 8B(msp430x) */
    __Boot_SharedCallbacks = 0xff70; /* Start of Shared callbacks */
     _BOOT_APPVECTOR = __Boot_SharedCallbacks;       /* Definition for application table             */
    _Appl_Vector_Start = 0xf3a2; /* Interrupt table */
    /* Reserved Flash locations for Application Area */
 
/* MEMORY definition, adjust based on definitions above */
MEMORY
{
    SFR                     : origin = 0x0000, length = 0x0010
    PERIPHERALS_8BIT        : origin = 0x0010, length = 0x00F0
    PERIPHERALS_16BIT       : origin = 0x0100, length = 0x0100
    // RAM from _NonReserved_RAM_Start - __RAM_End
    RAM                     : origin = 0x2008, length = 0x1ff8
    // Flash from _App_Start -> (APP_VECTORS-1)
    FLASH                   : origin = 0x8003, length = 0x739f
    FLASH2                  : origin = 0x10000, length = 0x8000
    // Interrupt table from  _App_Vector_Start->(RESET-1)
    INT00            : origin = 0xf3a2, length = 0x0002
    INT01            : origin = 0xf3a4, length = 0x0002
    INT02            : origin = 0xf3a6, length = 0x0002
    INT03            : origin = 0xf3a8, length = 0x0002
    INT04            : origin = 0xf3aa, length = 0x0002
    INT05            : origin = 0xf3ac, length = 0x0002
    INT06            : origin = 0xf3ae, length = 0x0002
    INT07            : origin = 0xf3b0, length = 0x0002
    INT08            : origin = 0xf3b2, length = 0x0002
    INT09            : origin = 0xf3b4, length = 0x0002
    INT10            : origin = 0xf3b6, length = 0x0002
    INT11            : origin = 0xf3b8, length = 0x0002
    INT12            : origin = 0xf3ba, length = 0x0002
    INT13            : origin = 0xf3bc, length = 0x0002
    INT14            : origin = 0xf3be, length = 0x0002
    INT15            : origin = 0xf3c0, length = 0x0002
    INT16            : origin = 0xf3c2, length = 0x0002
    INT17            : origin = 0xf3c4, length = 0x0002
    INT18            : origin = 0xf3c6, length = 0x0002
    INT19            : origin = 0xf3c8, length = 0x0002
    INT20            : origin = 0xf3ca, length = 0x0002
    INT21            : origin = 0xf3cc, length = 0x0002
    INT22            : origin = 0xf3ce, length = 0x0002
    INT23            : origin = 0xf3d0, length = 0x0002
    INT24            : origin = 0xf3d2, length = 0x0002
    INT25            : origin = 0xf3d4, length = 0x0002
    INT26            : origin = 0xf3d6, length = 0x0002
    INT27            : origin = 0xf3d8, length = 0x0002
    INT28            : origin = 0xf3da, length = 0x0002
    INT29            : origin = 0xf3dc, length = 0x0002
    INT30            : origin = 0xf3de, length = 0x0002
    INT31            : origin = 0xf3e0, length = 0x0002
    INT32            : origin = 0xf3e2, length = 0x0002
    INT33            : origin = 0xf3e4, length = 0x0002
    INT34            : origin = 0xf3e6, length = 0x0002
    INT35            : origin = 0xf3e8, length = 0x0002
    INT36            : origin = 0xf3ea, length = 0x0002
    INT37            : origin = 0xf3ec, length = 0x0002
    INT38            : origin = 0xf3ee, length = 0x0002
    INT39            : origin = 0xf3f0, length = 0x0002
    INT40            : origin = 0xf3f2, length = 0x0002
    INT41            : origin = 0xf3f4, length = 0x0002
    INT42            : origin = 0xf3f6, length = 0x0002
    INT43            : origin = 0xf3f8, length = 0x0002
    INT44            : origin = 0xf3fa, length = 0x0002
    INT45            : origin = 0xf3fc, length = 0x0002
    
    // App reset from _App_Reset_Vector
    RESET                   : origin = 0xf3fe, length = 0x0002
}

/****************************************************************************/
/* SPECIFY THE SECTIONS ALLOCATION INTO MEMORY                              */
/****************************************************************************/

SECTIONS
{
    .bss        : {} > RAM                /* GLOBAL & STATIC VARS              */
    .data       : {} > RAM                /* GLOBAL & STATIC VARS              */
    .sysmem     : {} > RAM                /* DYNAMIC MEMORY ALLOCATION AREA    */
    .stack      : {} > RAM (HIGH)         /* SOFTWARE SYSTEM STACK             */

    .text:_isr        : {}  > FLASH            /* Code ISRs                         */
    #ifndef __LARGE_DATA_MODEL__
	.text       : {} >> FLASH            /* CODE                 */
    #else 
	.text       : {} >> FLASH | FLASH2      /* CODE                 */
    #endif 
       .cinit      : {} > FLASH        /* INITIALIZATION TABLES*/ 
    #ifndef __LARGE_DATA_MODEL__ 
      .const      : {} >> FLASH       /* CONSTANT DATA        */ 
    #else 
      .const      : {} >> FLASH2 | FLASH    /* CONSTANT DATA        */ 
    #endif 

    .cio        : {} > RAM                /* C I/O BUFFER                      */

    /* MSP430 INTERRUPT VECTORS          */
    .int00       : {}               > INT00
    .int01       : {}               > INT01
    .int02       : {}               > INT02
    .int03       : {}               > INT03
    .int04       : {}               > INT04
    .int05       : {}               > INT05
    .int06       : {}               > INT06
    .int07       : {}               > INT07
    .int08       : {}               > INT08
    .int09       : {}               > INT09
    .int10       : {}               > INT10
    .int11       : {}               > INT11
    .int12       : {}               > INT12
    .int13       : {}               > INT13
    .int14       : {}               > INT14
    .int15       : {}               > INT15
    .int16       : {}               > INT16
    .int17       : {}               > INT17
    .int18       : {}               > INT18
    .int19       : {}               > INT19
    ECOMP0       : { * ( .int20 ) } > INT20 type = VECT_INIT
    PORT6        : { * ( .int21 ) } > INT21 type = VECT_INIT
    PORT5        : { * ( .int22 ) } > INT22 type = VECT_INIT
    PORT4        : { * ( .int23 ) } > INT23 type = VECT_INIT
    PORT3        : { * ( .int24 ) } > INT24 type = VECT_INIT
    PORT2        : { * ( .int25 ) } > INT25 type = VECT_INIT
    PORT1        : { * ( .int26 ) } > INT26 type = VECT_INIT
    ADC          : { * ( .int27 ) } > INT27 type = VECT_INIT
    EUSCI_B1     : { * ( .int28 ) } > INT28 type = VECT_INIT
    EUSCI_B0     : { * ( .int29 ) } > INT29 type = VECT_INIT
    EUSCI_A1     : { * ( .int30 ) } > INT30 type = VECT_INIT
    EUSCI_A0     : { * ( .int31 ) } > INT31 type = VECT_INIT
    WDT          : { * ( .int32 ) } > INT32 type = VECT_INIT
    RTC          : { * ( .int33 ) } > INT33 type = VECT_INIT
    TIMER0_B1    : { * ( .int34 ) } > INT34 type = VECT_INIT
    TIMER0_B0    : { * ( .int35 ) } > INT35 type = VECT_INIT
    TIMER3_A1    : { * ( .int36 ) } > INT36 type = VECT_INIT
    TIMER3_A0    : { * ( .int37 ) } > INT37 type = VECT_INIT
    TIMER2_A1    : { * ( .int38 ) } > INT38 type = VECT_INIT
    TIMER2_A0    : { * ( .int39 ) } > INT39 type = VECT_INIT
    TIMER1_A1    : { * ( .int40 ) } > INT40 type = VECT_INIT
    TIMER1_A0    : { * ( .int41 ) } > INT41 type = VECT_INIT
    TIMER0_A1    : { * ( .int42 ) } > INT42 type = VECT_INIT
    TIMER0_A0    : { * ( .int43 ) } > INT43 type = VECT_INIT
    UNMI         : { * ( .int44 ) } > INT44 type = VECT_INIT
    SYSNMI       : { * ( .int45 ) } > INT45 type = VECT_INIT

    .reset       : {}               > RESET  /* MSP430 RESET VECTOR                 */
}

/****************************************************************************/
/* INCLUDE PERIPHERALS MEMORY MAP                                           */
/****************************************************************************/

-l msp430fr2476.cmd

